==> async-graphql-extension-apollo-tracing-1.0.3.crate: async-graphql-extension-apollo-tracing-1.0.3/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.3]

### Misc

-   Commit Cargo.lock ... (idk why it was in the .gitignore)

## [1.0.2]

### Fix

-   Do not send Traces over than 4mb

## [1.0.1]

### Fix

-   Fix CI publish command, we can't build it with every features, we have to choose the runtime.

## [1.0.0]

### Feat

-   Add async-std-comp & tokio-comp features
-   Runtime agnostic

### Fix

-   Fix auto-release workflow

## [0.4.2]

### Fix

-   Fix auto-release

## [0.4.1]

### Misc

-   Update documentation

## [0.4.0]

### Feat

-   GZIP Compression

## [0.3.6]

### Misc

-   Update workflows
-   Update Cargo.toml Repository
-   Clippy fix

## [0.3.5]

### Fix

-   Fix tracing timings

## [0.3.4]

### Fix

-   Use offset for start time

## [0.3.3]

### Misc

-   Fix some README.md

## [0.3.2]

### Fix

-   Do not show authorization_token

## [0.3.1]

### Fix

-   Fix register schema

## [0.3.0]

### Feat

-   Add schema export to apollo

## [0.2.4]

### Fix

-   Make ApolloTracingDataExt fields public for hydratation

## [0.2.3]

### Fix

-   On merge fix token github

## [0.2.2]

### Fix

-   Merge deployment

## [0.2.1]

### Feat

-   Opensource Brevz Apollo Extension
-   Add on-merge workflows
-   Fix on-merge workflows

## [0.1.0]

### Added

-   Boot repo

[Unreleased]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.3...HEAD

[1.0.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.2...v1.0.3

[1.0.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.1...v1.0.2

[1.0.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.0...v1.0.1

[1.0.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.2...v1.0.0

[0.4.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.1...v0.4.2

[0.4.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.0...v0.4.1

[0.4.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.6...v0.4.0

[0.3.6]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.5...v0.3.6

[0.3.5]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.4...v0.3.5

[0.3.4]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.3...v0.3.4

[0.3.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.2...v0.3.3

[0.3.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.1...v0.3.2

[0.3.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.0...v0.3.1

[0.3.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.4...v0.3.0

[0.2.4]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.3...v0.2.4

[0.2.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.2...v0.2.3

[0.2.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.1...v0.2.2

[0.2.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.1.0...v0.2.1

==> async-graphql-extension-apollo-tracing-2.1.0.crate: async-graphql-extension-apollo-tracing-2.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [2.1.0]

### Feat

-   Bump `async-graphql` to `3.0.7`
-   Edition 2021

## [1.0.4]

### Fix

-   Bump `async-graphql` to `2.10.*` to fix dependency resolution conflict while using latest async-graphql.

### Misc

-   Add audit github action
-   Issue with workflow token

## [1.0.3]

### Misc

-   Commit Cargo.lock ... (idk why it was in the .gitignore)

## [1.0.2]

### Fix

-   Do not send Traces over than 4mb

## [1.0.1]

### Fix

-   Fix CI publish command, we can't build it with every features, we have to choose the runtime.

## [1.0.0]

### Feat

-   Add async-std-comp & tokio-comp features
-   Runtime agnostic

### Fix

-   Fix auto-release workflow

## [0.4.2]

### Fix

-   Fix auto-release

## [0.4.1]

### Misc

-   Update documentation

## [0.4.0]

### Feat

-   GZIP Compression

## [0.3.6]

### Misc

-   Update workflows
-   Update Cargo.toml Repository
-   Clippy fix

## [0.3.5]

### Fix

-   Fix tracing timings

## [0.3.4]

### Fix

-   Use offset for start time

## [0.3.3]

### Misc

-   Fix some README.md

## [0.3.2]

### Fix

-   Do not show authorization_token

## [0.3.1]

### Fix

-   Fix register schema

## [0.3.0]

### Feat

-   Add schema export to apollo

## [0.2.4]

### Fix

-   Make ApolloTracingDataExt fields public for hydratation

## [0.2.3]

### Fix

-   On merge fix token github

## [0.2.2]

### Fix

-   Merge deployment

## [0.2.1]

### Feat

-   Opensource Brevz Apollo Extension
-   Add on-merge workflows
-   Fix on-merge workflows

## [0.1.0]

### Added

-   Boot repo

[Unreleased]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v2.1.0...HEAD

[2.1.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.4...v2.1.0

[1.0.4]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.3...v1.0.4

[1.0.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.2...v1.0.3

[1.0.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.1...v1.0.2

[1.0.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v1.0.0...v1.0.1

[1.0.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.2...v1.0.0

[0.4.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.1...v0.4.2

[0.4.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.4.0...v0.4.1

[0.4.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.6...v0.4.0

[0.3.6]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.5...v0.3.6

[0.3.5]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.4...v0.3.5

[0.3.4]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.3...v0.3.4

[0.3.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.2...v0.3.3

[0.3.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.1...v0.3.2

[0.3.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.3.0...v0.3.1

[0.3.0]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.4...v0.3.0

[0.2.4]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.3...v0.2.4

[0.2.3]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.2...v0.2.3

[0.2.2]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.2.1...v0.2.2

[0.2.1]: https://github.com/Miaxos/async_graphql_apollo_studio_extension/compare/v0.1.0...v0.2.1
